summaryrefslogtreecommitdiffstats
path: root/khtml/rendering/render_list.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 04:12:51 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 04:12:51 +0000
commit560378aaca1784ba19806a0414a32b20c744de39 (patch)
treece0dfd7c3febf2a1adc7603d1019a8be2083c415 /khtml/rendering/render_list.h
parentd4d5af1cdbd3cc65d095e0afc5b1f4260091cf5d (diff)
downloadtdelibs-560378aaca1784ba19806a0414a32b20c744de39.tar.gz
tdelibs-560378aaca1784ba19806a0414a32b20c744de39.zip
Automated conversion for enhanced compatibility with TQt for Qt4 3.4.0 TP1
NOTE: This will not compile with Qt4 (yet), however it does compile with Qt3 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1211081 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'khtml/rendering/render_list.h')
-rw-r--r--khtml/rendering/render_list.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/khtml/rendering/render_list.h b/khtml/rendering/render_list.h
index b70132671..84c7d0906 100644
--- a/khtml/rendering/render_list.h
+++ b/khtml/rendering/render_list.h
@@ -58,7 +58,7 @@ public:
void setValue( long v ) { predefVal = v; }
- virtual void layout( );
+ virtual void tqlayout( );
virtual void detach( );
virtual void calcMinMaxWidth();
//virtual short marginLeft() const;
@@ -89,11 +89,11 @@ public:
virtual void setStyle(RenderStyle *style);
virtual const char *renderName() const { return "RenderListMarker"; }
// so the marker gets to layout itself. Only needed for
// list-style-position: inside
virtual void paint(PaintInfo& i, int xoff, int yoff);
- virtual void layout( );
+ virtual void tqlayout( );
virtual void calcMinMaxWidth();
virtual short lineHeight( bool firstLine ) const;
@@ -123,7 +123,7 @@ protected:
};
// Implementation of list-item counter
-// ### should replace most list-item specific code in renderObject::getCounter
+// ### should tqreplace most list-item specific code in renderObject::getCounter
/*
class CounterListItem : public CounterNode
{
@@ -89,11 +89,11 @@ public:
virtual void setStyle(RenderStyle *style);
virtual const char *renderName() const { return "RenderListMarker"; }
- // so the marker gets to layout itself. Only needed for
+ // so the marker gets to tqlayout itself. Only needed for
// list-style-position: inside
virtual void paint(PaintInfo& i, int xoff, int yoff);